==> QLC%2B_4.12.6.tar.gz: qlcplus-QLC-_4.12.6/webaccess/src/webaccess_cz_CZ.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs_CZ">
<context>
    <name>WebAccess</name>
    <message>
        <location filename="webaccess.cpp" line="169"/>
        <source>Loading project...</source>
        <translation>Načítání projektu...</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="205"/>
        <source>Fixture stored and loaded</source>
        <translation>Zařízení uložena a načtena</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="396"/>
        <source>Username and password are required fields.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="402"/>
        <location filename="webaccess.cpp" line="427"/>
        <source>User level has to be a positive integer.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="421"/>
        <source>Username is required.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="439"/>
        <source>Error while saving passwords file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="454"/>
        <source>Network configuration changed. Reboot to apply the changes.</source>
        <translation>Konfigurace sítě byla změněna. Restartuje pro aplikování změn.</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="473"/>
        <source>Autostart configuration changed</source>
        <translation>Postartovní konfigurace změněna</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="822"/>
        <source>Widget not supported (yet) for web access</source>
        <translation>Ovládací prvek (zatím) není podporován pro vzdálený přístup</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="873"/>
        <location filename="webaccess.cpp" line="925"/>
        <source>Page</source>
        <translation>Strana</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1088"/>
        <source>Enable</source>
        <translation>Zapnout</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1120"/>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1121"/>
        <source>Fade In</source>
        <translation>Zesílení</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1122"/>
        <source>Fade Out</source>
        <translation>Zeslabení</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1123"/>
        <source>Duration</source>
        <translation>Trvání</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1124"/>
        <source>Notes</source>
        <translation>Poznámky</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1360"/>
        <source>Load project</source>
        <translation>Načíst projekt</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1362"/>
        <source>Simple Desk</source>
        <translation>Jednoduchý pult</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1364"/>
        <source>Configuration</source>
        <translation>Konfigurace</translation>
    </message>
</context>
<context>
    <name>WebAccessConfiguration</name>
    <message>
        <location filename="webaccessconfiguration.cpp" line="136"/>
        <source>Passthrough</source>
        <translation>Průchozí</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="210"/>
        <source>Load fixture</source>
        <translation>Načíst zařízení</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="221"/>
        <source>Username</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="222"/>
        <source>Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="223"/>
        <source>Access level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="224"/>
        <source>Action</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="235"/>
        <source>Leave blank to not change</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="242"/>
        <location filename="webaccessconfiguration.cpp" line="272"/>
        <source>Only Virtual Console</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="247"/>
        <location filename="webaccessconfiguration.cpp" line="274"/>
        <source>Virtual Console and Simple Desk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="252"/>
        <location filename="webaccessconfiguration.cpp" line="276"/>
        <source>Everything</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="258"/>
        <location filename="webaccessconfiguration.cpp" line="283"/>
        <source>Change</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="260"/>
        <location filename="webaccessconfiguration.cpp" line="283"/>
        <source>Delete user</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="266"/>
        <source>New username...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="267"/>
        <location filename="webaccessconfiguration.cpp" line="285"/>
        <source>New password...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="284"/>
        <source>Username and password are required fields.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="287"/>
        <source>Add user</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="292"/>
        <source>Note: if there isn&apos;t at least one user with access level &quot;Everything&quot; on the list authorization will be disabled.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="323"/>
        <source>System</source>
        <translation>Systém</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="332"/>
        <source>Back</source>
        <translation>Zpět</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="340"/>
        <source>Universes configuration</source>
        <translation>Konfigurace větví</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="347"/>
        <source>Audio configuration</source>
        <translation>Konfigurace zvuku</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="355"/>
        <source>User loaded fixtures</source>
        <translation>Uživatelem načtená zařízení</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="364"/>
        <source>Authorized users</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WebAccessNetwork</name>
    <message>
        <location filename="webaccessnetwork.cpp" line="101"/>
        <source>Network interface: </source>
        <translation>Sítová karta:</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="106"/>
        <source>Access point name (SSID): </source>
        <translation>Název bezdrátového přístupového bodu (SSID):</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="108"/>
        <source>WPA-PSK Password: </source>
        <translation>WPA-PSK Heslo:</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="113"/>
        <source>Dynamic (DHCP)</source>
        <translation>Dynamická (DHCP)</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="115"/>
        <source>Static</source>
        <translation>Statická</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="119"/>
        <source>IP Address: </source>
        <translation>IP Adresa:</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="121"/>
        <source>Netmask: </source>
        <translation>Maska podsítě:</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="123"/>
        <source>Gateway: </source>
        <translation>Výchozí brána:</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="126"/>
        <location filename="webaccessnetwork.cpp" line="344"/>
        <source>Apply changes</source>
        <translation>Použít změny</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="327"/>
        <source>Back</source>
        <translation>Zpět</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="333"/>
        <source>Network configuration</source>
        <translation>Konfigurace sítě</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="338"/>
        <source>Project autostart</source>
        <translation>Automatický start projektu</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="342"/>
        <source>No project</source>
        <translation>Žádný zvolený projekt</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="343"/>
        <source>Use current project</source>
        <translation>Použít aktuální projekt</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="348"/>
        <source>Reboot</source>
        <translation>Restartovat</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="349"/>
        <source>Shutdown</source>
        <translation>Vypnout</translation>
    </message>
</context>
<context>
    <name>WebAccessSimpleDesk</name>
    <message>
        <location filename="webaccesssimpledesk.cpp" line="50"/>
        <source>Back</source>
        <translation>Zpět</translation>
    </message>
    <message>
        <location filename="webaccesssimpledesk.cpp" line="56"/>
        <source>Page</source>
        <translation>Strana</translation>
    </message>
    <message>
        <location filename="webaccesssimpledesk.cpp" line="57"/>
        <source>Previous page</source>
        <translation>Předchozí strana</translation>
    </message>
    <message>
        <location filename="webaccesssimpledesk.cpp" line="65"/>
        <source>Next page</source>
        <translation>Následující strana</translation>
    </message>
    <message>
        <location filename="webaccesssimpledesk.cpp" line="68"/>
        <source>Reset universe</source>
        <translation>Resetovat větve</translation>
    </message>
    <message>
        <location filename="webaccesssimpledesk.cpp" line="70"/>
        <source>Universe</source>
        <translation>Větev</translation>
    </message>
</context>
</TS>

==> QLC%2B_4.14.0.tar.gz: qlcplus-QLC-_4.14.0/webaccess/src/webaccess_cz_CZ.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs_CZ">
<context>
    <name>WebAccess</name>
    <message>
        <location filename="webaccess.cpp" line="172"/>
        <source>Loading project...</source>
        <translation>Načítání projektu...</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="208"/>
        <source>Fixture stored and loaded</source>
        <translation>Zařízení uložena a načtena</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="408"/>
        <source>Username and password are required fields.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="414"/>
        <location filename="webaccess.cpp" line="439"/>
        <source>User level has to be a positive integer.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="433"/>
        <source>Username is required.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="451"/>
        <source>Error while saving passwords file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="466"/>
        <source>Network configuration changed. Reboot to apply the changes.</source>
        <translation>Konfigurace sítě byla změněna. Restartuje pro aplikování změn.</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="468"/>
        <source>An error occurred while updating the network configuration.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="484"/>
        <source>Wi-Fi hotspot successfully activated.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="486"/>
        <source>An error occurred while creating a Wi-Fi hotspot.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="491"/>
        <source>Wi-Fi hotspot successfully deactivated.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="507"/>
        <source>Autostart configuration changed</source>
        <translation>Postartovní konfigurace změněna</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1014"/>
        <source>Widget not supported (yet) for web access</source>
        <translation>Ovládací prvek (zatím) není podporován pro vzdálený přístup</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1440"/>
        <source>Enable</source>
        <translation>Zapnout</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1643"/>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1644"/>
        <source>Fade In</source>
        <translation>Zesílení</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1645"/>
        <source>Fade Out</source>
        <translation>Zeslabení</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1646"/>
        <source>Duration</source>
        <translation>Trvání</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="1647"/>
        <source>Notes</source>
        <translation>Poznámky</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="2076"/>
        <source>Color 2 Reset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="2085"/>
        <source>Color 3 Reset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="2094"/>
        <source>Color 4 Reset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="2103"/>
        <source>Color 5 Reset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="2345"/>
        <source>Load project</source>
        <translation>Načíst projekt</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="2347"/>
        <source>Simple Desk</source>
        <translation>Jednoduchý pult</translation>
    </message>
    <message>
        <location filename="webaccess.cpp" line="2349"/>
        <source>Configuration</source>
        <translation>Konfigurace</translation>
    </message>
</context>
<context>
    <name>WebAccessConfiguration</name>
    <message>
        <location filename="webaccessconfiguration.cpp" line="136"/>
        <source>Passthrough</source>
        <translation>Průchozí</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="210"/>
        <source>Load fixture</source>
        <translation>Načíst zařízení</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="221"/>
        <source>Username</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="222"/>
        <source>Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="223"/>
        <source>Access level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="224"/>
        <source>Action</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="235"/>
        <source>Leave blank to not change</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="242"/>
        <location filename="webaccessconfiguration.cpp" line="272"/>
        <source>Only Virtual Console</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="247"/>
        <location filename="webaccessconfiguration.cpp" line="274"/>
        <source>Virtual Console and Simple Desk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="252"/>
        <location filename="webaccessconfiguration.cpp" line="276"/>
        <source>Everything</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="258"/>
        <location filename="webaccessconfiguration.cpp" line="283"/>
        <source>Change</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="260"/>
        <location filename="webaccessconfiguration.cpp" line="283"/>
        <source>Delete user</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="266"/>
        <source>New username...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="267"/>
        <location filename="webaccessconfiguration.cpp" line="285"/>
        <source>New password...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="284"/>
        <source>Username and password are required fields.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="287"/>
        <source>Add user</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="292"/>
        <source>Note: if there isn&apos;t at least one user with access level &quot;Everything&quot; on the list authorization will be disabled.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="322"/>
        <source>System</source>
        <translation>Systém</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="331"/>
        <source>Back</source>
        <translation>Zpět</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="339"/>
        <source>Universes configuration</source>
        <translation>Konfigurace větví</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="346"/>
        <source>Audio configuration</source>
        <translation>Konfigurace zvuku</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="354"/>
        <source>User loaded fixtures</source>
        <translation>Uživatelem načtená zařízení</translation>
    </message>
    <message>
        <location filename="webaccessconfiguration.cpp" line="363"/>
        <source>Authorized users</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WebAccessNetwork</name>
    <message>
        <location filename="webaccessnetwork.cpp" line="114"/>
        <source>Wi-Fi Hotspot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="118"/>
        <location filename="webaccessnetwork.cpp" line="136"/>
        <source>Access point name (SSID): </source>
        <translation>Název bezdrátového přístupového bodu (SSID):</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="120"/>
        <location filename="webaccessnetwork.cpp" line="138"/>
        <source>WPA-PSK Password: </source>
        <translation>WPA-PSK Heslo:</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="124"/>
        <source>Enable</source>
        <translation type="unfinished">Zapnout</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="125"/>
        <source>Disable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="130"/>
        <source>Network interface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="144"/>
        <source>Dynamic (DHCP)</source>
        <translation>Dynamická (DHCP)</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="146"/>
        <source>Static</source>
        <translation>Statická</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="151"/>
        <source>IP Address: </source>
        <translation>IP Adresa:</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="153"/>
        <source>Netmask: </source>
        <translation>Maska podsítě:</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="155"/>
        <source>Gateway: </source>
        <translation>Výchozí brána:</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="158"/>
        <location filename="webaccessnetwork.cpp" line="343"/>
        <source>Apply changes</source>
        <translation>Použít změny</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="326"/>
        <source>Back</source>
        <translation>Zpět</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="332"/>
        <source>Network configuration</source>
        <translation>Konfigurace sítě</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="337"/>
        <source>Project autostart</source>
        <translation>Automatický start projektu</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="341"/>
        <source>No project</source>
        <translation>Žádný zvolený projekt</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="342"/>
        <source>Use current project</source>
        <translation>Použít aktuální projekt</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="347"/>
        <source>Reboot</source>
        <translation>Restartovat</translation>
    </message>
    <message>
        <location filename="webaccessnetwork.cpp" line="348"/>
        <source>Shutdown</source>
        <translation>Vypnout</translation>
    </message>
</context>
<context>
    <name>WebAccessSimpleDesk</name>
    <message>
        <location filename="webaccesssimpledesk.cpp" line="50"/>
        <source>Back</source>
        <translation>Zpět</translation>
    </message>
    <message>
        <location filename="webaccesssimpledesk.cpp" line="56"/>
        <source>Page</source>
        <translation>Strana</translation>
    </message>
    <message>
        <location filename="webaccesssimpledesk.cpp" line="57"/>
        <source>Previous page</source>
        <translation>Předchozí strana</translation>
    </message>
    <message>
        <location filename="webaccesssimpledesk.cpp" line="65"/>
        <source>Next page</source>
        <translation>Následující strana</translation>
    </message>
    <message>
        <location filename="webaccesssimpledesk.cpp" line="68"/>
        <source>Reset universe</source>
        <translation>Resetovat větve</translation>
    </message>
    <message>
        <location filename="webaccesssimpledesk.cpp" line="70"/>
        <source>Universe</source>
        <translation>Větev</translation>
    </message>
</context>
</TS>
